/* gstglconfig.h
 */

#ifndef __GST_GL_CONFIG_H__
#define __GST_GL_CONFIG_H__

#include <gst/gst.h>

G_BEGIN_DECLS


#define GST_GL_HAVE_OPENGL 1
#define GST_GL_HAVE_GLES2 1
#define GST_GL_HAVE_GLES3 1
#define GST_GL_HAVE_GLES3EXT3_H 1

#define GST_GL_HAVE_WINDOW_X11 1
#define GST_GL_HAVE_WINDOW_COCOA 0
#define GST_GL_HAVE_WINDOW_WIN32 0
#define GST_GL_HAVE_WINDOW_WINRT 0
#define GST_GL_HAVE_WINDOW_WAYLAND 1
#define GST_GL_HAVE_WINDOW_ANDROID 0
#define GST_GL_HAVE_WINDOW_DISPMANX 0
#define GST_GL_HAVE_WINDOW_EAGL 0
#define GST_GL_HAVE_WINDOW_VIV_FB 0
#define GST_GL_HAVE_WINDOW_GBM 1

#define GST_GL_HAVE_PLATFORM_EGL 1
#define GST_GL_HAVE_PLATFORM_GLX 1
#define GST_GL_HAVE_PLATFORM_WGL 0
#define GST_GL_HAVE_PLATFORM_CGL 0
#define GST_GL_HAVE_PLATFORM_EAGL 0

#define GST_GL_HAVE_DMABUF 1
#define GST_GL_HAVE_VIV_DIRECTVIV 0

#define GST_GL_HAVE_GLEGLIMAGEOES 1
#define GST_GL_HAVE_GLCHAR 1
#define GST_GL_HAVE_GLSIZEIPTR 1
#define GST_GL_HAVE_GLINTPTR 1
#define GST_GL_HAVE_GLSYNC 1
#define GST_GL_HAVE_GLUINT64 1
#define GST_GL_HAVE_GLINT64 1
#define GST_GL_HAVE_EGLATTRIB 1
#define GST_GL_HAVE_EGLUINT64KHR 1

G_END_DECLS

#endif  /* __GST_GL_CONFIG_H__ */
